StatusCodeHandler class abstract

Implementers

Constructors

StatusCodeHandler({required int statusCode, required void callback()})
const

Properties

callback → void Function()
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final

Methods

handle(Response response) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited