Gateway class abstract
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
{String? path, required Method method, Map< String, dynamic> ? params, Map<String, dynamic> ? body, Map<String, dynamic> ? headers, Map<int, Function> statusCodeHandlers = const {}}) → Future -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited