FlTheme class

Constructors

FlTheme({String? fontFamily, Color primaryColor = Colors.green, Color secondaryColor = Colors.lime, Color tertiaryColor = Colors.orange})

Properties

hashCode int
The hash code for this object.
no setterinherited
primaryColor Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryColor Color
final
tertiaryColor Color
final

Methods

darkTheme() ThemeData
lightTheme() ThemeData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

borderRadius → const double
borderRadiusFull → const double
borderRadiusLg → const double
borderRadiusSm → const double
padding → const double
paddingLg → const double
paddingSm → const double
spacing → const double
spacingLg → const double
spacingSm → const double
spacingXs → const double