Select<T> class

Inheritance

Constructors

Select({Key? key, required SelectController<T> controller, void onSelected(T?)?, List<Pair<T>> pairs = const [], String? placeholder, bool isResettable = false, SelectStyle selectStyle = SelectStyle.classic})
const

Properties

controller SelectController<T>
final
hashCode int
The hash code for this object.
no setterinherited
isResettable bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onSelected → void Function(T?)?
final
pairs List<Pair<T>>
final
placeholder String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectStyle SelectStyle
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<Select<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited